"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.batch_job_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BatchJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class BatchJobMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
        START_DATE_TIME_FIELD_NUMBER: builtins.int
        COMPLETION_DATE_TIME_FIELD_NUMBER: builtins.int
        ESTIMATED_COMPLETION_RATIO_FIELD_NUMBER: builtins.int
        OPERATION_COUNT_FIELD_NUMBER: builtins.int
        EXECUTED_OPERATION_COUNT_FIELD_NUMBER: builtins.int
        creation_date_time: typing.Text = ...
        start_date_time: typing.Text = ...
        completion_date_time: typing.Text = ...
        estimated_completion_ratio: builtins.float = ...
        operation_count: builtins.int = ...
        executed_operation_count: builtins.int = ...
        def __init__(
            self,
            *,
            creation_date_time: typing.Text = ...,
            start_date_time: typing.Text = ...,
            completion_date_time: typing.Text = ...,
            estimated_completion_ratio: builtins.float = ...,
            operation_count: builtins.int = ...,
            executed_operation_count: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_completion_date_time",
                b"_completion_date_time",
                "_creation_date_time",
                b"_creation_date_time",
                "_estimated_completion_ratio",
                b"_estimated_completion_ratio",
                "_executed_operation_count",
                b"_executed_operation_count",
                "_operation_count",
                b"_operation_count",
                "_start_date_time",
                b"_start_date_time",
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_completion_date_time",
                b"_completion_date_time",
                "_creation_date_time",
                b"_creation_date_time",
                "_estimated_completion_ratio",
                b"_estimated_completion_ratio",
                "_executed_operation_count",
                b"_executed_operation_count",
                "_operation_count",
                b"_operation_count",
                "_start_date_time",
                b"_start_date_time",
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_completion_date_time", b"_completion_date_time"
            ],
        ) -> typing_extensions.Literal["completion_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions.Literal["creation_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_estimated_completion_ratio", b"_estimated_completion_ratio"
            ],
        ) -> typing_extensions.Literal["estimated_completion_ratio"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_executed_operation_count", b"_executed_operation_count"
            ],
        ) -> typing_extensions.Literal["executed_operation_count"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_operation_count", b"_operation_count"
            ],
        ) -> typing_extensions.Literal["operation_count"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions.Literal["start_date_time"]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NEXT_ADD_SEQUENCE_TOKEN_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LONG_RUNNING_OPERATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    next_add_sequence_token: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.batch_job_status_pb2.BatchJobStatusEnum.BatchJobStatus.V = (
        ...
    )
    long_running_operation: typing.Text = ...
    @property
    def metadata(self) -> global___BatchJob.BatchJobMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        next_add_sequence_token: typing.Text = ...,
        metadata: typing.Optional[global___BatchJob.BatchJobMetadata] = ...,
        status: google.ads.google_ads.v6.proto.enums.batch_job_status_pb2.BatchJobStatusEnum.BatchJobStatus.V = ...,
        long_running_operation: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_next_add_sequence_token",
            b"_next_add_sequence_token",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_next_add_sequence_token",
            b"_next_add_sequence_token",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions.Literal["long_running_operation"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_next_add_sequence_token", b"_next_add_sequence_token"
        ],
    ) -> typing_extensions.Literal["next_add_sequence_token"]: ...

global___BatchJob = BatchJob



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.custom_audience_pb2
import grpc

from .custom_audience_service_pb2 import *

class CustomAudienceServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomAudience(
        self,
        request: global___GetCustomAudienceRequest,
    ) -> google.ads.google_ads.v6.proto.resources.custom_audience_pb2.CustomAudience: ...
    def MutateCustomAudiences(
        self,
        request: global___MutateCustomAudiencesRequest,
    ) -> global___MutateCustomAudiencesResponse: ...

class CustomAudienceServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomAudience(
        self,
        request: global___GetCustomAudienceRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.custom_audience_pb2.CustomAudience: ...
    @abc.abstractmethod
    def MutateCustomAudiences(
        self,
        request: global___MutateCustomAudiencesRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomAudiencesResponse: ...

def add_CustomAudienceServiceServicer_to_server(
    servicer: CustomAudienceServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QueryError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QueryError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QueryErrorEnum.QueryError.V(0)
        UNKNOWN = QueryErrorEnum.QueryError.V(1)
        QUERY_ERROR = QueryErrorEnum.QueryError.V(50)
        BAD_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(18)
        BAD_ESCAPE_SEQUENCE = QueryErrorEnum.QueryError.V(7)
        BAD_FIELD_NAME = QueryErrorEnum.QueryError.V(12)
        BAD_LIMIT_VALUE = QueryErrorEnum.QueryError.V(15)
        BAD_NUMBER = QueryErrorEnum.QueryError.V(5)
        BAD_OPERATOR = QueryErrorEnum.QueryError.V(3)
        BAD_PARAMETER_NAME = QueryErrorEnum.QueryError.V(61)
        BAD_PARAMETER_VALUE = QueryErrorEnum.QueryError.V(62)
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(45)
        BAD_SYMBOL = QueryErrorEnum.QueryError.V(2)
        BAD_VALUE = QueryErrorEnum.QueryError.V(4)
        DATE_RANGE_TOO_WIDE = QueryErrorEnum.QueryError.V(36)
        DATE_RANGE_TOO_NARROW = QueryErrorEnum.QueryError.V(60)
        EXPECTED_AND = QueryErrorEnum.QueryError.V(30)
        EXPECTED_BY = QueryErrorEnum.QueryError.V(14)
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(37)
        EXPECTED_FILTERS_ON_DATE_RANGE = QueryErrorEnum.QueryError.V(55)
        EXPECTED_FROM = QueryErrorEnum.QueryError.V(44)
        EXPECTED_LIST = QueryErrorEnum.QueryError.V(41)
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(16)
        EXPECTED_SELECT = QueryErrorEnum.QueryError.V(13)
        EXPECTED_SINGLE_VALUE = QueryErrorEnum.QueryError.V(42)
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(29)
        INVALID_DATE_FORMAT = QueryErrorEnum.QueryError.V(38)
        INVALID_STRING_VALUE = QueryErrorEnum.QueryError.V(57)
        INVALID_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(26)
        INVALID_VALUE_WITH_DURING_OPERATOR = QueryErrorEnum.QueryError.V(22)
        INVALID_VALUE_WITH_LIKE_OPERATOR = QueryErrorEnum.QueryError.V(56)
        OPERATOR_FIELD_MISMATCH = QueryErrorEnum.QueryError.V(35)
        PROHIBITED_EMPTY_LIST_IN_CONDITION = QueryErrorEnum.QueryError.V(28)
        PROHIBITED_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(54)
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(31)
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = QueryErrorEnum.QueryError.V(40)
        PROHIBITED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(23)
        PROHIBITED_FIELD_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(24)
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(43)
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(48)
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(58)
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(49)
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(51)
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = (
            QueryErrorEnum.QueryError.V(53)
        )
        LIMIT_VALUE_TOO_LOW = QueryErrorEnum.QueryError.V(25)
        PROHIBITED_NEWLINE_IN_STRING = QueryErrorEnum.QueryError.V(8)
        PROHIBITED_VALUE_COMBINATION_IN_LIST = QueryErrorEnum.QueryError.V(10)
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = (
            QueryErrorEnum.QueryError.V(21)
        )
        STRING_NOT_TERMINATED = QueryErrorEnum.QueryError.V(6)
        TOO_MANY_SEGMENTS = QueryErrorEnum.QueryError.V(34)
        UNEXPECTED_END_OF_QUERY = QueryErrorEnum.QueryError.V(9)
        UNEXPECTED_FROM_CLAUSE = QueryErrorEnum.QueryError.V(47)
        UNRECOGNIZED_FIELD = QueryErrorEnum.QueryError.V(32)
        UNEXPECTED_INPUT = QueryErrorEnum.QueryError.V(11)
        REQUESTED_METRICS_FOR_MANAGER = QueryErrorEnum.QueryError.V(59)
        FILTER_HAS_TOO_MANY_VALUES = QueryErrorEnum.QueryError.V(63)
    class QueryError(metaclass=_QueryError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QueryErrorEnum.QueryError.V(0)
    UNKNOWN = QueryErrorEnum.QueryError.V(1)
    QUERY_ERROR = QueryErrorEnum.QueryError.V(50)
    BAD_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(18)
    BAD_ESCAPE_SEQUENCE = QueryErrorEnum.QueryError.V(7)
    BAD_FIELD_NAME = QueryErrorEnum.QueryError.V(12)
    BAD_LIMIT_VALUE = QueryErrorEnum.QueryError.V(15)
    BAD_NUMBER = QueryErrorEnum.QueryError.V(5)
    BAD_OPERATOR = QueryErrorEnum.QueryError.V(3)
    BAD_PARAMETER_NAME = QueryErrorEnum.QueryError.V(61)
    BAD_PARAMETER_VALUE = QueryErrorEnum.QueryError.V(62)
    BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(45)
    BAD_SYMBOL = QueryErrorEnum.QueryError.V(2)
    BAD_VALUE = QueryErrorEnum.QueryError.V(4)
    DATE_RANGE_TOO_WIDE = QueryErrorEnum.QueryError.V(36)
    DATE_RANGE_TOO_NARROW = QueryErrorEnum.QueryError.V(60)
    EXPECTED_AND = QueryErrorEnum.QueryError.V(30)
    EXPECTED_BY = QueryErrorEnum.QueryError.V(14)
    EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(37)
    EXPECTED_FILTERS_ON_DATE_RANGE = QueryErrorEnum.QueryError.V(55)
    EXPECTED_FROM = QueryErrorEnum.QueryError.V(44)
    EXPECTED_LIST = QueryErrorEnum.QueryError.V(41)
    EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(16)
    EXPECTED_SELECT = QueryErrorEnum.QueryError.V(13)
    EXPECTED_SINGLE_VALUE = QueryErrorEnum.QueryError.V(42)
    EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(29)
    INVALID_DATE_FORMAT = QueryErrorEnum.QueryError.V(38)
    INVALID_STRING_VALUE = QueryErrorEnum.QueryError.V(57)
    INVALID_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(26)
    INVALID_VALUE_WITH_DURING_OPERATOR = QueryErrorEnum.QueryError.V(22)
    INVALID_VALUE_WITH_LIKE_OPERATOR = QueryErrorEnum.QueryError.V(56)
    OPERATOR_FIELD_MISMATCH = QueryErrorEnum.QueryError.V(35)
    PROHIBITED_EMPTY_LIST_IN_CONDITION = QueryErrorEnum.QueryError.V(28)
    PROHIBITED_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(54)
    PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(31)
    PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = QueryErrorEnum.QueryError.V(40)
    PROHIBITED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(23)
    PROHIBITED_FIELD_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(24)
    PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(43)
    PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(48)
    PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(58)
    PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(49)
    PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(51)
    PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = (
        QueryErrorEnum.QueryError.V(53)
    )
    LIMIT_VALUE_TOO_LOW = QueryErrorEnum.QueryError.V(25)
    PROHIBITED_NEWLINE_IN_STRING = QueryErrorEnum.QueryError.V(8)
    PROHIBITED_VALUE_COMBINATION_IN_LIST = QueryErrorEnum.QueryError.V(10)
    PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(21)
    STRING_NOT_TERMINATED = QueryErrorEnum.QueryError.V(6)
    TOO_MANY_SEGMENTS = QueryErrorEnum.QueryError.V(34)
    UNEXPECTED_END_OF_QUERY = QueryErrorEnum.QueryError.V(9)
    UNEXPECTED_FROM_CLAUSE = QueryErrorEnum.QueryError.V(47)
    UNRECOGNIZED_FIELD = QueryErrorEnum.QueryError.V(32)
    UNEXPECTED_INPUT = QueryErrorEnum.QueryError.V(11)
    REQUESTED_METRICS_FOR_MANAGER = QueryErrorEnum.QueryError.V(59)
    FILTER_HAS_TOO_MANY_VALUES = QueryErrorEnum.QueryError.V(63)
    def __init__(
        self,
    ) -> None: ...

global___QueryErrorEnum = QueryErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.criteria_pb2
import google.ads.google_ads.v6.proto.enums.bid_modifier_source_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupBidModifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    CRITERION_ID_FIELD_NUMBER: builtins.int
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    BASE_AD_GROUP_FIELD_NUMBER: builtins.int
    BID_MODIFIER_SOURCE_FIELD_NUMBER: builtins.int
    HOTEL_DATE_SELECTION_TYPE_FIELD_NUMBER: builtins.int
    HOTEL_ADVANCE_BOOKING_WINDOW_FIELD_NUMBER: builtins.int
    HOTEL_LENGTH_OF_STAY_FIELD_NUMBER: builtins.int
    HOTEL_CHECK_IN_DAY_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    PREFERRED_CONTENT_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    ad_group: typing.Text = ...
    criterion_id: builtins.int = ...
    bid_modifier: builtins.float = ...
    base_ad_group: typing.Text = ...
    bid_modifier_source: google.ads.google_ads.v6.proto.enums.bid_modifier_source_pb2.BidModifierSourceEnum.BidModifierSource.V = (
        ...
    )
    @property
    def hotel_date_selection_type(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.HotelDateSelectionTypeInfo: ...
    @property
    def hotel_advance_booking_window(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.HotelAdvanceBookingWindowInfo: ...
    @property
    def hotel_length_of_stay(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.HotelLengthOfStayInfo: ...
    @property
    def hotel_check_in_day(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.HotelCheckInDayInfo: ...
    @property
    def device(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.DeviceInfo: ...
    @property
    def preferred_content(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.PreferredContentInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        ad_group: typing.Text = ...,
        criterion_id: builtins.int = ...,
        bid_modifier: builtins.float = ...,
        base_ad_group: typing.Text = ...,
        bid_modifier_source: google.ads.google_ads.v6.proto.enums.bid_modifier_source_pb2.BidModifierSourceEnum.BidModifierSource.V = ...,
        hotel_date_selection_type: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.HotelDateSelectionTypeInfo
        ] = ...,
        hotel_advance_booking_window: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.HotelAdvanceBookingWindowInfo
        ] = ...,
        hotel_length_of_stay: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.HotelLengthOfStayInfo
        ] = ...,
        hotel_check_in_day: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.HotelCheckInDayInfo
        ] = ...,
        device: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.DeviceInfo
        ] = ...,
        preferred_content: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.PreferredContentInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_base_ad_group",
            b"_base_ad_group",
            "_bid_modifier",
            b"_bid_modifier",
            "_criterion_id",
            b"_criterion_id",
            "ad_group",
            b"ad_group",
            "base_ad_group",
            b"base_ad_group",
            "bid_modifier",
            b"bid_modifier",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "device",
            b"device",
            "hotel_advance_booking_window",
            b"hotel_advance_booking_window",
            "hotel_check_in_day",
            b"hotel_check_in_day",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "preferred_content",
            b"preferred_content",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_base_ad_group",
            b"_base_ad_group",
            "_bid_modifier",
            b"_bid_modifier",
            "_criterion_id",
            b"_criterion_id",
            "ad_group",
            b"ad_group",
            "base_ad_group",
            b"base_ad_group",
            "bid_modifier",
            b"bid_modifier",
            "bid_modifier_source",
            b"bid_modifier_source",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "device",
            b"device",
            "hotel_advance_booking_window",
            b"hotel_advance_booking_window",
            "hotel_check_in_day",
            b"hotel_check_in_day",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "preferred_content",
            b"preferred_content",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions.Literal["ad_group"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_base_ad_group", b"_base_ad_group"],
    ) -> typing_extensions.Literal["base_ad_group"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bid_modifier", b"_bid_modifier"]
    ) -> typing_extensions.Literal["bid_modifier"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_criterion_id", b"_criterion_id"]
    ) -> typing_extensions.Literal["criterion_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["criterion", b"criterion"]
    ) -> typing_extensions.Literal[
        "hotel_date_selection_type",
        "hotel_advance_booking_window",
        "hotel_length_of_stay",
        "hotel_check_in_day",
        "device",
        "preferred_content",
    ]: ...

global___AdGroupBidModifier = AdGroupBidModifier



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionFeedItemErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExtensionFeedItemError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtensionFeedItemError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(0)
        UNKNOWN = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(1)
        VALUE_OUT_OF_RANGE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(2)
        URL_LIST_TOO_LONG = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(3)
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(4)
        )
        CANNOT_SET_WITH_FINAL_URLS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(5)
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(6)
        )
        INVALID_PHONE_NUMBER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(7)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(8)
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(9)
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(10)
        )
        DISALLOWED_NUMBER_TYPE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(11)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(12)
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(13)
        )
        INVALID_CALL_CONVERSION_ACTION = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(14)
        )
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(15)
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(16)
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(17)
        )
        INVALID_APP_ID = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(18)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(19)
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(20)
        )
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(21)
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(22)
        )
        INCONSISTENT_CURRENCY_CODES = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(23)
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(24)
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(25)
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(26)
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(27)
        )
        UNSUPPORTED_VALUE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(28)
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(29)
        )
        INVALID_DEVICE_PREFERENCE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
            30
        )
        INVALID_SCHEDULE_END = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(31)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(32)
        )
        INVALID_SNIPPETS_HEADER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
            33
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(34)
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(35)
        )
        CONFLICTING_CALL_CONVERSION_SETTINGS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(36)
        )
        EXTENSION_TYPE_MISMATCH = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
            37
        )
        EXTENSION_SUBTYPE_REQUIRED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(38)
        )
        EXTENSION_TYPE_UNSUPPORTED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(39)
        )
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(40)
        )
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(41)
        )
        INVALID_PRICE_FORMAT = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(42)
        PROMOTION_INVALID_TIME = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(43)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(44)
        )
        CONCRETE_EXTENSION_TYPE_REQUIRED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(45)
        )
        SCHEDULE_END_NOT_AFTER_START = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(46)
        )
    class ExtensionFeedItemError(metaclass=_ExtensionFeedItemError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(0)
    UNKNOWN = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(1)
    VALUE_OUT_OF_RANGE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(2)
    URL_LIST_TOO_LONG = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(3)
    CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(4)
    )
    CANNOT_SET_WITH_FINAL_URLS = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(5)
    CANNOT_SET_WITHOUT_FINAL_URLS = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
        6
    )
    INVALID_PHONE_NUMBER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(7)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(8)
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(9)
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(10)
    )
    DISALLOWED_NUMBER_TYPE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(11)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(12)
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(13)
    )
    INVALID_CALL_CONVERSION_ACTION = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(14)
    )
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(15)
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(16)
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(17)
    )
    INVALID_APP_ID = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(18)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(19)
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(20)
    )
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(21)
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(22)
    )
    INCONSISTENT_CURRENCY_CODES = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
        23
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(24)
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(25)
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(26)
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(27)
    )
    UNSUPPORTED_VALUE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(28)
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(29)
    )
    INVALID_DEVICE_PREFERENCE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(30)
    INVALID_SCHEDULE_END = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(31)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(32)
    )
    INVALID_SNIPPETS_HEADER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(33)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(34)
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(35)
    )
    CONFLICTING_CALL_CONVERSION_SETTINGS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(36)
    )
    EXTENSION_TYPE_MISMATCH = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(37)
    EXTENSION_SUBTYPE_REQUIRED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(38)
    EXTENSION_TYPE_UNSUPPORTED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(39)
    CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(40)
    )
    CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(41)
    )
    INVALID_PRICE_FORMAT = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(42)
    PROMOTION_INVALID_TIME = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(43)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(44)
    )
    CONCRETE_EXTENSION_TYPE_REQUIRED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(45)
    )
    SCHEDULE_END_NOT_AFTER_START = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
        46
    )
    def __init__(
        self,
    ) -> None: ...

global___ExtensionFeedItemErrorEnum = ExtensionFeedItemErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.batch_job_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BatchJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class BatchJobMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
        COMPLETION_DATE_TIME_FIELD_NUMBER: builtins.int
        ESTIMATED_COMPLETION_RATIO_FIELD_NUMBER: builtins.int
        OPERATION_COUNT_FIELD_NUMBER: builtins.int
        EXECUTED_OPERATION_COUNT_FIELD_NUMBER: builtins.int
        @property
        def creation_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def completion_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def estimated_completion_ratio(
            self,
        ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
        @property
        def operation_count(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def executed_operation_count(
            self,
        ) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            creation_date_time: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            completion_date_time: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            estimated_completion_ratio: typing.Optional[
                google.protobuf.wrappers_pb2.DoubleValue
            ] = ...,
            operation_count: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
            executed_operation_count: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NEXT_ADD_SEQUENCE_TOKEN_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LONG_RUNNING_OPERATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v4.proto.enums.batch_job_status_pb2.BatchJobStatusEnum.BatchJobStatus.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def next_add_sequence_token(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def metadata(self) -> global___BatchJob.BatchJobMetadata: ...
    @property
    def long_running_operation(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        next_add_sequence_token: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        metadata: typing.Optional[global___BatchJob.BatchJobMetadata] = ...,
        status: google.ads.google_ads.v4.proto.enums.batch_job_status_pb2.BatchJobStatusEnum.BatchJobStatus.V = ...,
        long_running_operation: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

global___BatchJob = BatchJob



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_extension_setting_pb2
import grpc

from .ad_group_extension_setting_service_pb2 import *

class AdGroupExtensionSettingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupExtensionSetting(
        self,
        request: global___GetAdGroupExtensionSettingRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_extension_setting_pb2.AdGroupExtensionSetting: ...
    def MutateAdGroupExtensionSettings(
        self,
        request: global___MutateAdGroupExtensionSettingsRequest,
    ) -> global___MutateAdGroupExtensionSettingsResponse: ...

class AdGroupExtensionSettingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupExtensionSetting(
        self,
        request: global___GetAdGroupExtensionSettingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_extension_setting_pb2.AdGroupExtensionSetting: ...
    @abc.abstractmethod
    def MutateAdGroupExtensionSettings(
        self,
        request: global___MutateAdGroupExtensionSettingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupExtensionSettingsResponse: ...

def add_AdGroupExtensionSettingServiceServicer_to_server(
    servicer: AdGroupExtensionSettingServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerManagerLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerManagerLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerManagerLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(0)
        UNKNOWN = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(1)
        NO_PENDING_INVITE = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(2)
        SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(3)
        )
        MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(4)
        )
        CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(5)
        )
        CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(6)
        )
        CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(7)
        )
        CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(8)
        )
        DUPLICATE_CHILD_FOUND = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(
            9
        )
        TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(10)
        )
    class CustomerManagerLinkError(metaclass=_CustomerManagerLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(0)
    UNKNOWN = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(1)
    NO_PENDING_INVITE = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(2)
    SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(3)
    )
    MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(4)
    )
    CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(5)
    )
    CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(6)
    )
    CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(7)
    )
    CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(8)
    )
    DUPLICATE_CHILD_FOUND = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(9)
    TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(10)
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerManagerLinkErrorEnum = CustomerManagerLinkErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_label_pb2
import grpc

from .ad_group_label_service_pb2 import *

class AdGroupLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupLabel(
        self,
        request: global___GetAdGroupLabelRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_label_pb2.AdGroupLabel: ...
    def MutateAdGroupLabels(
        self,
        request: global___MutateAdGroupLabelsRequest,
    ) -> global___MutateAdGroupLabelsResponse: ...

class AdGroupLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupLabel(
        self,
        request: global___GetAdGroupLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_label_pb2.AdGroupLabel: ...
    @abc.abstractmethod
    def MutateAdGroupLabels(
        self,
        request: global___MutateAdGroupLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupLabelsResponse: ...

def add_AdGroupLabelServiceServicer_to_server(
    servicer: AdGroupLabelServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanCampaignErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _KeywordPlanCampaignError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            KeywordPlanCampaignError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(0)
        UNKNOWN = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(1)
        INVALID_NAME = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(2)
        INVALID_LANGUAGES = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(3)
        INVALID_GEOS = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(4)
        DUPLICATE_NAME = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(5)
        MAX_GEOS_EXCEEDED = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(6)
        MAX_LANGUAGES_EXCEEDED = (
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(7)
        )
    class KeywordPlanCampaignError(metaclass=_KeywordPlanCampaignError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(0)
    UNKNOWN = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(1)
    INVALID_NAME = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(2)
    INVALID_LANGUAGES = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(3)
    INVALID_GEOS = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(4)
    DUPLICATE_NAME = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(5)
    MAX_GEOS_EXCEEDED = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(6)
    MAX_LANGUAGES_EXCEEDED = KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___KeywordPlanCampaignErrorEnum = KeywordPlanCampaignErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemValidationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemValidationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemValidationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemValidationErrorEnum.FeedItemValidationError.V(0)
        UNKNOWN = FeedItemValidationErrorEnum.FeedItemValidationError.V(1)
        STRING_TOO_SHORT = FeedItemValidationErrorEnum.FeedItemValidationError.V(2)
        STRING_TOO_LONG = FeedItemValidationErrorEnum.FeedItemValidationError.V(3)
        VALUE_NOT_SPECIFIED = FeedItemValidationErrorEnum.FeedItemValidationError.V(4)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(5)
        )
        INVALID_PHONE_NUMBER = FeedItemValidationErrorEnum.FeedItemValidationError.V(6)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(7)
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(8)
        )
        DISALLOWED_NUMBER_TYPE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            9
        )
        VALUE_OUT_OF_RANGE = FeedItemValidationErrorEnum.FeedItemValidationError.V(10)
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(11)
        )
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(12)
        )
        INVALID_COUNTRY_CODE = FeedItemValidationErrorEnum.FeedItemValidationError.V(13)
        INVALID_APP_ID = FeedItemValidationErrorEnum.FeedItemValidationError.V(14)
        MISSING_ATTRIBUTES_FOR_FIELDS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(15)
        )
        INVALID_TYPE_ID = FeedItemValidationErrorEnum.FeedItemValidationError.V(16)
        INVALID_EMAIL_ADDRESS = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            17
        )
        INVALID_HTTPS_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(18)
        MISSING_DELIVERY_ADDRESS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(19)
        )
        START_DATE_AFTER_END_DATE = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(20)
        )
        MISSING_FEED_ITEM_START_TIME = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(21)
        )
        MISSING_FEED_ITEM_END_TIME = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(22)
        )
        MISSING_FEED_ITEM_ID = FeedItemValidationErrorEnum.FeedItemValidationError.V(23)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(24)
        )
        INVALID_REVIEW_EXTENSION_SNIPPET = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(25)
        )
        INVALID_NUMBER_FORMAT = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            26
        )
        INVALID_DATE_FORMAT = FeedItemValidationErrorEnum.FeedItemValidationError.V(27)
        INVALID_PRICE_FORMAT = FeedItemValidationErrorEnum.FeedItemValidationError.V(28)
        UNKNOWN_PLACEHOLDER_FIELD = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(29)
        )
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(30)
        )
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(31)
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(32)
        )
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(33)
        )
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(34)
        )
        INVALID_FORM_ENCODED_PARAMS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(35)
        )
        INVALID_URL_PARAMETER_NAME = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(36)
        )
        NO_GEOCODING_RESULT = FeedItemValidationErrorEnum.FeedItemValidationError.V(37)
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(38)
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(39)
        )
        INVALID_PLACEHOLDER_FIELD_ID = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(40)
        )
        INVALID_URL_TAG = FeedItemValidationErrorEnum.FeedItemValidationError.V(41)
        LIST_TOO_LONG = FeedItemValidationErrorEnum.FeedItemValidationError.V(42)
        INVALID_ATTRIBUTES_COMBINATION = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(43)
        )
        DUPLICATE_VALUES = FeedItemValidationErrorEnum.FeedItemValidationError.V(44)
        INVALID_CALL_CONVERSION_ACTION_ID = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(45)
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(46)
        )
        APP_ID_DOESNT_EXIST_IN_APP_STORE = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(47)
        )
        INVALID_FINAL_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(48)
        INVALID_TRACKING_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(49)
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(50)
        )
        LIST_TOO_SHORT = FeedItemValidationErrorEnum.FeedItemValidationError.V(51)
        INVALID_USER_ACTION = FeedItemValidationErrorEnum.FeedItemValidationError.V(52)
        INVALID_TYPE_NAME = FeedItemValidationErrorEnum.FeedItemValidationError.V(53)
        INVALID_EVENT_CHANGE_STATUS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(54)
        )
        INVALID_SNIPPETS_HEADER = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            55
        )
        INVALID_ANDROID_APP_LINK = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(56)
        )
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(57)
        )
        RESERVED_KEYWORD_OTHER = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            58
        )
        DUPLICATE_OPTION_LABELS = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            59
        )
        DUPLICATE_OPTION_PREFILLS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(60)
        )
        UNEQUAL_LIST_LENGTHS = FeedItemValidationErrorEnum.FeedItemValidationError.V(61)
        INCONSISTENT_CURRENCY_CODES = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(62)
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(63)
        )
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(64)
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(65)
        )
        UNSUPPORTED_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(66)
        INVALID_FINAL_MOBILE_URL = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(67)
        )
        INVALID_KEYWORDLESS_AD_RULE_LABEL = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(68)
        )
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(69)
        )
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(70)
        )
        INVALID_IOS_APP_LINK = FeedItemValidationErrorEnum.FeedItemValidationError.V(71)
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(72)
        )
        PROMOTION_INVALID_TIME = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            73
        )
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(74)
        )
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(75)
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(76)
        )
        AD_CUSTOMIZERS_NOT_ALLOWED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(77)
        )
        INVALID_LANGUAGE_CODE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            78
        )
        UNSUPPORTED_LANGUAGE = FeedItemValidationErrorEnum.FeedItemValidationError.V(79)
        IF_FUNCTION_NOT_ALLOWED = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            80
        )
        INVALID_FINAL_URL_SUFFIX = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(81)
        )
        INVALID_TAG_IN_FINAL_URL_SUFFIX = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(82)
        )
        INVALID_FINAL_URL_SUFFIX_FORMAT = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(83)
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(84)
        )
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(85)
        )
        NO_DELIVERY_OPTION_IS_SET = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(86)
        )
        INVALID_CONVERSION_REPORTING_STATE = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(87)
        )
        IMAGE_SIZE_WRONG = FeedItemValidationErrorEnum.FeedItemValidationError.V(88)
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(89)
        )
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = (
            FeedItemValidationErrorEnum.FeedItemValidationError.V(90)
        )
        INVALID_LATITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            91
        )
        INVALID_LONGITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            92
        )
        TOO_MANY_LABELS = FeedItemValidationErrorEnum.FeedItemValidationError.V(93)
        INVALID_IMAGE_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(94)
        MISSING_LATITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            95
        )
        MISSING_LONGITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            96
        )
        ADDRESS_NOT_FOUND = FeedItemValidationErrorEnum.FeedItemValidationError.V(97)
        ADDRESS_NOT_TARGETABLE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
            98
        )
    class FeedItemValidationError(metaclass=_FeedItemValidationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemValidationErrorEnum.FeedItemValidationError.V(0)
    UNKNOWN = FeedItemValidationErrorEnum.FeedItemValidationError.V(1)
    STRING_TOO_SHORT = FeedItemValidationErrorEnum.FeedItemValidationError.V(2)
    STRING_TOO_LONG = FeedItemValidationErrorEnum.FeedItemValidationError.V(3)
    VALUE_NOT_SPECIFIED = FeedItemValidationErrorEnum.FeedItemValidationError.V(4)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(5)
    )
    INVALID_PHONE_NUMBER = FeedItemValidationErrorEnum.FeedItemValidationError.V(6)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(7)
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(8)
    )
    DISALLOWED_NUMBER_TYPE = FeedItemValidationErrorEnum.FeedItemValidationError.V(9)
    VALUE_OUT_OF_RANGE = FeedItemValidationErrorEnum.FeedItemValidationError.V(10)
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(11)
    )
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(12)
    )
    INVALID_COUNTRY_CODE = FeedItemValidationErrorEnum.FeedItemValidationError.V(13)
    INVALID_APP_ID = FeedItemValidationErrorEnum.FeedItemValidationError.V(14)
    MISSING_ATTRIBUTES_FOR_FIELDS = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(15)
    )
    INVALID_TYPE_ID = FeedItemValidationErrorEnum.FeedItemValidationError.V(16)
    INVALID_EMAIL_ADDRESS = FeedItemValidationErrorEnum.FeedItemValidationError.V(17)
    INVALID_HTTPS_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(18)
    MISSING_DELIVERY_ADDRESS = FeedItemValidationErrorEnum.FeedItemValidationError.V(19)
    START_DATE_AFTER_END_DATE = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        20
    )
    MISSING_FEED_ITEM_START_TIME = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(21)
    )
    MISSING_FEED_ITEM_END_TIME = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        22
    )
    MISSING_FEED_ITEM_ID = FeedItemValidationErrorEnum.FeedItemValidationError.V(23)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(24)
    )
    INVALID_REVIEW_EXTENSION_SNIPPET = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(25)
    )
    INVALID_NUMBER_FORMAT = FeedItemValidationErrorEnum.FeedItemValidationError.V(26)
    INVALID_DATE_FORMAT = FeedItemValidationErrorEnum.FeedItemValidationError.V(27)
    INVALID_PRICE_FORMAT = FeedItemValidationErrorEnum.FeedItemValidationError.V(28)
    UNKNOWN_PLACEHOLDER_FIELD = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        29
    )
    MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(30)
    )
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(31)
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(32)
    )
    DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(33)
    )
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(34)
    )
    INVALID_FORM_ENCODED_PARAMS = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        35
    )
    INVALID_URL_PARAMETER_NAME = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        36
    )
    NO_GEOCODING_RESULT = FeedItemValidationErrorEnum.FeedItemValidationError.V(37)
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(38)
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(39)
    )
    INVALID_PLACEHOLDER_FIELD_ID = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(40)
    )
    INVALID_URL_TAG = FeedItemValidationErrorEnum.FeedItemValidationError.V(41)
    LIST_TOO_LONG = FeedItemValidationErrorEnum.FeedItemValidationError.V(42)
    INVALID_ATTRIBUTES_COMBINATION = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(43)
    )
    DUPLICATE_VALUES = FeedItemValidationErrorEnum.FeedItemValidationError.V(44)
    INVALID_CALL_CONVERSION_ACTION_ID = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(45)
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(46)
    )
    APP_ID_DOESNT_EXIST_IN_APP_STORE = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(47)
    )
    INVALID_FINAL_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(48)
    INVALID_TRACKING_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(49)
    INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(50)
    )
    LIST_TOO_SHORT = FeedItemValidationErrorEnum.FeedItemValidationError.V(51)
    INVALID_USER_ACTION = FeedItemValidationErrorEnum.FeedItemValidationError.V(52)
    INVALID_TYPE_NAME = FeedItemValidationErrorEnum.FeedItemValidationError.V(53)
    INVALID_EVENT_CHANGE_STATUS = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        54
    )
    INVALID_SNIPPETS_HEADER = FeedItemValidationErrorEnum.FeedItemValidationError.V(55)
    INVALID_ANDROID_APP_LINK = FeedItemValidationErrorEnum.FeedItemValidationError.V(56)
    NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(57)
    )
    RESERVED_KEYWORD_OTHER = FeedItemValidationErrorEnum.FeedItemValidationError.V(58)
    DUPLICATE_OPTION_LABELS = FeedItemValidationErrorEnum.FeedItemValidationError.V(59)
    DUPLICATE_OPTION_PREFILLS = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        60
    )
    UNEQUAL_LIST_LENGTHS = FeedItemValidationErrorEnum.FeedItemValidationError.V(61)
    INCONSISTENT_CURRENCY_CODES = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        62
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(63)
    )
    ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(64)
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(65)
    )
    UNSUPPORTED_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(66)
    INVALID_FINAL_MOBILE_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(67)
    INVALID_KEYWORDLESS_AD_RULE_LABEL = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(68)
    )
    VALUE_TRACK_PARAMETER_NOT_SUPPORTED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(69)
    )
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(70)
    )
    INVALID_IOS_APP_LINK = FeedItemValidationErrorEnum.FeedItemValidationError.V(71)
    MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(72)
    )
    PROMOTION_INVALID_TIME = FeedItemValidationErrorEnum.FeedItemValidationError.V(73)
    PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(74)
    )
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(75)
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(76)
    )
    AD_CUSTOMIZERS_NOT_ALLOWED = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        77
    )
    INVALID_LANGUAGE_CODE = FeedItemValidationErrorEnum.FeedItemValidationError.V(78)
    UNSUPPORTED_LANGUAGE = FeedItemValidationErrorEnum.FeedItemValidationError.V(79)
    IF_FUNCTION_NOT_ALLOWED = FeedItemValidationErrorEnum.FeedItemValidationError.V(80)
    INVALID_FINAL_URL_SUFFIX = FeedItemValidationErrorEnum.FeedItemValidationError.V(81)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(82)
    )
    INVALID_FINAL_URL_SUFFIX_FORMAT = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(83)
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(84)
    )
    ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(85)
    )
    NO_DELIVERY_OPTION_IS_SET = FeedItemValidationErrorEnum.FeedItemValidationError.V(
        86
    )
    INVALID_CONVERSION_REPORTING_STATE = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(87)
    )
    IMAGE_SIZE_WRONG = FeedItemValidationErrorEnum.FeedItemValidationError.V(88)
    EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(89)
    )
    AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = (
        FeedItemValidationErrorEnum.FeedItemValidationError.V(90)
    )
    INVALID_LATITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(91)
    INVALID_LONGITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(92)
    TOO_MANY_LABELS = FeedItemValidationErrorEnum.FeedItemValidationError.V(93)
    INVALID_IMAGE_URL = FeedItemValidationErrorEnum.FeedItemValidationError.V(94)
    MISSING_LATITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(95)
    MISSING_LONGITUDE_VALUE = FeedItemValidationErrorEnum.FeedItemValidationError.V(96)
    ADDRESS_NOT_FOUND = FeedItemValidationErrorEnum.FeedItemValidationError.V(97)
    ADDRESS_NOT_TARGETABLE = FeedItemValidationErrorEnum.FeedItemValidationError.V(98)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemValidationErrorEnum = FeedItemValidationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionCountingTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionCountingType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionCountingType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(0)
        UNKNOWN = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(1)
        ONE_PER_CLICK = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(
            2
        )
        MANY_PER_CLICK = (
            ConversionActionCountingTypeEnum.ConversionActionCountingType.V(3)
        )
    class ConversionActionCountingType(metaclass=_ConversionActionCountingType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(0)
    UNKNOWN = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(1)
    ONE_PER_CLICK = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(2)
    MANY_PER_CLICK = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionCountingTypeEnum = ConversionActionCountingTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PromotionExtensionOccasionEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PromotionExtensionOccasion(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PromotionExtensionOccasion.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(0)
        UNKNOWN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(1)
        NEW_YEARS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(2)
        CHINESE_NEW_YEAR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(
            3
        )
        VALENTINES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(4)
        EASTER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(5)
        MOTHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(6)
        FATHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(7)
        LABOR_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(8)
        BACK_TO_SCHOOL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(9)
        HALLOWEEN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(10)
        BLACK_FRIDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(11)
        CYBER_MONDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(12)
        CHRISTMAS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(13)
        BOXING_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(14)
        INDEPENDENCE_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(
            15
        )
        NATIONAL_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(16)
        END_OF_SEASON = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(17)
        WINTER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(18)
        SUMMER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(19)
        FALL_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(20)
        SPRING_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(21)
        RAMADAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(22)
        EID_AL_FITR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(23)
        EID_AL_ADHA = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(24)
        SINGLES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(25)
        WOMENS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(26)
        HOLI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(27)
        PARENTS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(28)
        ST_NICHOLAS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(
            29
        )
        CARNIVAL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(30)
        EPIPHANY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(31)
        ROSH_HASHANAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(32)
        PASSOVER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(33)
        HANUKKAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(34)
        DIWALI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(35)
        NAVRATRI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(36)
        SONGKRAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(37)
        YEAR_END_GIFT = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(38)
    class PromotionExtensionOccasion(metaclass=_PromotionExtensionOccasion):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(0)
    UNKNOWN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(1)
    NEW_YEARS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(2)
    CHINESE_NEW_YEAR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(3)
    VALENTINES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(4)
    EASTER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(5)
    MOTHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(6)
    FATHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(7)
    LABOR_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(8)
    BACK_TO_SCHOOL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(9)
    HALLOWEEN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(10)
    BLACK_FRIDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(11)
    CYBER_MONDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(12)
    CHRISTMAS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(13)
    BOXING_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(14)
    INDEPENDENCE_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(15)
    NATIONAL_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(16)
    END_OF_SEASON = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(17)
    WINTER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(18)
    SUMMER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(19)
    FALL_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(20)
    SPRING_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(21)
    RAMADAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(22)
    EID_AL_FITR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(23)
    EID_AL_ADHA = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(24)
    SINGLES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(25)
    WOMENS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(26)
    HOLI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(27)
    PARENTS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(28)
    ST_NICHOLAS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(29)
    CARNIVAL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(30)
    EPIPHANY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(31)
    ROSH_HASHANAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(32)
    PASSOVER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(33)
    HANUKKAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(34)
    DIWALI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(35)
    NAVRATRI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(36)
    SONGKRAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(37)
    YEAR_END_GIFT = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(38)
    def __init__(
        self,
    ) -> None: ...

global___PromotionExtensionOccasionEnum = PromotionExtensionOccasionEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.ad_group_criterion_pb2
import grpc

from .ad_group_criterion_service_pb2 import *

class AdGroupCriterionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupCriterion(
        self,
        request: global___GetAdGroupCriterionRequest,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_criterion_pb2.AdGroupCriterion: ...
    def MutateAdGroupCriteria(
        self,
        request: global___MutateAdGroupCriteriaRequest,
    ) -> global___MutateAdGroupCriteriaResponse: ...

class AdGroupCriterionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupCriterion(
        self,
        request: global___GetAdGroupCriterionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_criterion_pb2.AdGroupCriterion: ...
    @abc.abstractmethod
    def MutateAdGroupCriteria(
        self,
        request: global___MutateAdGroupCriteriaRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupCriteriaResponse: ...

def add_AdGroupCriterionServiceServicer_to_server(
    servicer: AdGroupCriterionServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerMatchUploadKeyTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerMatchUploadKeyType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerMatchUploadKeyType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(0)
        UNKNOWN = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(1)
        CONTACT_INFO = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(2)
        CRM_ID = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(3)
        MOBILE_ADVERTISING_ID = (
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(4)
        )
    class CustomerMatchUploadKeyType(metaclass=_CustomerMatchUploadKeyType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(0)
    UNKNOWN = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(1)
    CONTACT_INFO = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(2)
    CRM_ID = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(3)
    MOBILE_ADVERTISING_ID = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(
        4
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerMatchUploadKeyTypeEnum = CustomerMatchUploadKeyTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.change_status_operation_pb2
import google.ads.google_ads.v4.proto.enums.change_status_resource_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    LAST_CHANGE_DATE_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    RESOURCE_STATUS_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    FEED_ITEM_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    resource_type: google.ads.google_ads.v4.proto.enums.change_status_resource_type_pb2.ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V = (
        ...
    )
    resource_status: google.ads.google_ads.v4.proto.enums.change_status_operation_pb2.ChangeStatusOperationEnum.ChangeStatusOperation.V = (
        ...
    )
    @property
    def last_change_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_ad(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_criterion(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_criterion(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def feed_item(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_bid_modifier(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        last_change_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        resource_type: google.ads.google_ads.v4.proto.enums.change_status_resource_type_pb2.ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V = ...,
        campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        resource_status: google.ads.google_ads.v4.proto.enums.change_status_operation_pb2.ChangeStatusOperationEnum.ChangeStatusOperation.V = ...,
        ad_group_ad: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group_criterion: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        campaign_criterion: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        feed_item: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group_feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        campaign_feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group_bid_modifier: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_feed",
            b"ad_group_feed",
            "campaign",
            b"campaign",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_feed",
            b"campaign_feed",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "last_change_date_time",
            b"last_change_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_feed",
            b"ad_group_feed",
            "campaign",
            b"campaign",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_feed",
            b"campaign_feed",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "last_change_date_time",
            b"last_change_date_time",
            "resource_name",
            b"resource_name",
            "resource_status",
            b"resource_status",
            "resource_type",
            b"resource_type",
        ],
    ) -> None: ...

global___ChangeStatus = ChangeStatus



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatusErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeStatusError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeStatusError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(0)
        UNKNOWN = ChangeStatusErrorEnum.ChangeStatusError.V(1)
        START_DATE_TOO_OLD = ChangeStatusErrorEnum.ChangeStatusError.V(3)
        CHANGE_DATE_RANGE_INFINITE = ChangeStatusErrorEnum.ChangeStatusError.V(4)
        CHANGE_DATE_RANGE_NEGATIVE = ChangeStatusErrorEnum.ChangeStatusError.V(5)
        LIMIT_NOT_SPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(6)
        INVALID_LIMIT_CLAUSE = ChangeStatusErrorEnum.ChangeStatusError.V(7)
    class ChangeStatusError(metaclass=_ChangeStatusError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(0)
    UNKNOWN = ChangeStatusErrorEnum.ChangeStatusError.V(1)
    START_DATE_TOO_OLD = ChangeStatusErrorEnum.ChangeStatusError.V(3)
    CHANGE_DATE_RANGE_INFINITE = ChangeStatusErrorEnum.ChangeStatusError.V(4)
    CHANGE_DATE_RANGE_NEGATIVE = ChangeStatusErrorEnum.ChangeStatusError.V(5)
    LIMIT_NOT_SPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(6)
    INVALID_LIMIT_CLAUSE = ChangeStatusErrorEnum.ChangeStatusError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___ChangeStatusErrorEnum = ChangeStatusErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PriceExtensionPriceUnitEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PriceExtensionPriceUnit(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PriceExtensionPriceUnit.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(0)
        UNKNOWN = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(1)
        PER_HOUR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(2)
        PER_DAY = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(3)
        PER_WEEK = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(4)
        PER_MONTH = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(5)
        PER_YEAR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(6)
        PER_NIGHT = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(7)
    class PriceExtensionPriceUnit(metaclass=_PriceExtensionPriceUnit):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(0)
    UNKNOWN = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(1)
    PER_HOUR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(2)
    PER_DAY = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(3)
    PER_WEEK = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(4)
    PER_MONTH = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(5)
    PER_YEAR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(6)
    PER_NIGHT = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PriceExtensionPriceUnitEnum = PriceExtensionPriceUnitEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupCriterionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupCriterionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdGroupCriterionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(0)
        UNKNOWN = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(1)
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(2)
        )
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(3)
        )
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(4)
        )
        TOO_MANY_OPERATIONS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(5)
        CANT_UPDATE_NEGATIVE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(6)
        CONCRETE_TYPE_REQUIRED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(7)
        BID_INCOMPATIBLE_WITH_ADGROUP = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(8)
        )
        CANNOT_TARGET_AND_EXCLUDE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(9)
        ILLEGAL_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(10)
        INVALID_KEYWORD_TEXT = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(11)
        INVALID_DESTINATION_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(12)
        MISSING_DESTINATION_URL_TAG = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(
            13
        )
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(14)
        )
        INVALID_USER_STATUS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(15)
        CANNOT_ADD_CRITERIA_TYPE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(16)
        CANNOT_EXCLUDE_CRITERIA_TYPE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(17)
        )
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(27)
        )
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(28)
        )
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(29)
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(30)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(31)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(32)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(33)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(34)
        )
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(35)
        )
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(36)
        )
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(37)
        )
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(38)
        )
    class AdGroupCriterionError(metaclass=_AdGroupCriterionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(0)
    UNKNOWN = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(1)
    AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(2)
    )
    AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(3)
    )
    CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(4)
    )
    TOO_MANY_OPERATIONS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(5)
    CANT_UPDATE_NEGATIVE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(6)
    CONCRETE_TYPE_REQUIRED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(7)
    BID_INCOMPATIBLE_WITH_ADGROUP = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(8)
    CANNOT_TARGET_AND_EXCLUDE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(9)
    ILLEGAL_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(10)
    INVALID_KEYWORD_TEXT = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(11)
    INVALID_DESTINATION_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(12)
    MISSING_DESTINATION_URL_TAG = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(13)
    KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(14)
    )
    INVALID_USER_STATUS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(15)
    CANNOT_ADD_CRITERIA_TYPE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(16)
    CANNOT_EXCLUDE_CRITERIA_TYPE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(17)
    CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(27)
    )
    OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(28)
    )
    CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(29)
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(
        30
    )
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(31)
    )
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(32)
    )
    CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(33)
    )
    CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(34)
    )
    CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(35)
    )
    CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(36)
    )
    FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(37)
    )
    FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(38)
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupCriterionErrorEnum = AdGroupCriterionErrorEnum
